@@ -90,7 +90,8 @@ gs_plugin_setup_networking (GsPlugin *plugin, GError **error)
 	/* set up a session */
 	plugin->priv->session = soup_session_sync_new_with_options (SOUP_SESSION_USER_AGENT,
 								    "gnome-software",
-								    SOUP_SESSION_TIMEOUT, 5000,
+								    SOUP_SESSION_TIMEOUT, 60,
+								    SOUP_SESSION_IDLE_TIMEOUT, 60,
 								    NULL);
 	if (plugin->priv->session == NULL) {
 		g_set_error (error,
@@ -177,7 +178,7 @@ gs_plugin_refine_app (GsPlugin *plugin, GsApp *app, GError **error)
 		return TRUE;
 
 	/* create runtime dir and download */
-	if (!gs_mkdir_parent (as_icon_get_prefix (ic), error))
+	if (!gs_mkdir_parent (as_icon_get_filename (ic), error))
 		return FALSE;
 	if (!gs_plugin_icons_download (plugin,
 				       as_icon_get_url (ic),
